# vim: set ts=4 sw=4 et:
#
# spec file for package plzip
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           plzip
Version:        1.4
Release:        6.3
Summary:        Parallel LZMA Data Compressor
License:        GPL-2.0+
Group:          Productivity/Archiving/Compression
Url:            http://www.nongnu.org/lzip/plzip.html

Source:         http://download.savannah.gnu.org/releases/lzip/plzip/%name-%version.tar.gz
Source2:        http://download.savannah.gnu.org/releases/lzip/plzip/%name-%version.tar.gz.sig
Source3:        %name.keyring
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  gcc-c++
BuildRequires:  lzlib-devel
PreReq:         %install_info_prereq

%description
Plzip is a parallel version of the lzip data compressor. The files
produced by plzip are fully compatible with lzip-1.4 or newer. Plzip
is intended for faster compression/decompression of big files on
multiprocessor machines.

Lzip is a lossless data compressor based on the LZMA algorithm, with
very safe integrity checking and a user interface similar to the one
of gzip or bzip2. Lzip decompresses almost as fast as gzip and
compresses better than bzip2, which makes it well suited for software
distribution and data archiving.

%prep
%setup -q

%build
mkdir build
pushd build
# not autoconf
../configure \
    --prefix="%{_prefix}" \
    --bindir="%{_bindir}" \
    --datadir="%{_datadir}" \
    --includedir="%{_includedir}" \
    --infodir="%{_infodir}" \
    --libdir="%{_libdir}" \
    --mandir="%{_mandir}" \
    --sysconfdir="%{_sysconfdir}" \
    --enable-shared \
    CXX="%__cxx" \
    CPPFLAGS="%{optflags}" \
    CXXFLAGS="%{optflags}"
make %{?_smp_flags}
popd

%install
pushd build
%make_install LDCONFIG=echo
popd

%check
pushd build
make check
popd

%post
%install_info --info-dir="%_infodir" "%_infodir/%name.info%ext_info"

%postun
%install_info_delete --info-dir="%_infodir" "%_infodir/%name.info%ext_info"

%files
%defattr(-,root,root)
%doc AUTHORS ChangeLog COPYING NEWS README
%{_bindir}/plzip
%doc %{_infodir}/plzip.info%{ext_info}
%doc %{_mandir}/man1/plzip.1%{ext_man}

%changelog
* Thu Aug  6 2015 jengelh@inai.de
- Update to new upstream release 1.4
  * The option "-0" has been modified to use the new fast encoder of
  lzlib 1.7, which achieves a compression speed and ratio
  comparable to those of pigz's default compression level.
* Sun Feb  8 2015 jengelh@inai.de
- Update to new upstream release 1.3
  * Testing of a non-seekable file or of standard input now uses up
  to 30 MiB less memory per thread.
  * "-dvvv" and "-tvvv" now show the dictionary size of the first
  member, producing the same output as lzip for single-member
  files.
* Wed Oct  1 2014 jengelh@inai.de
- Update to new upstream release 1.2
  * Copying of file dates, permissions, and ownership now behaves
  like `cp -p`. (If the user ID or the group ID cannot be
  duplicated, the file permission bits S_ISUID and S_ISGID are
  cleared).
  * Individual limits have been set on the number of packets produced
  by each decompresor worker thread to limit the amount of memory
  used in all cases.
  * The license has been changed to GPL version 2 or later.
* Tue Sep 23 2014 jengelh@inai.de
- Drop gpg-offline build-time requirement; this is now handled by
  the local source validator
* Sun Sep 29 2013 jengelh@inai.de
- Update to new upstream release 1.1
  * Plzip now shows the progress of compression at verbosity
  level 2 (-vv).
* Wed Jun  5 2013 jengelh@inai.de
- Update to new upstream release 1.0
  * Scalability of compression (max number of useful worker threads)
  has been increased. Scalability when decompressing from/to
  regular files has been increased.
  * The number of worker threads is now limited to the number of
  members in the input file when decompressing from a regular file.
- Do signature verification
- Wrap description at 70 cols
- Remove redundant %%clean section
* Thu Apr 19 2012 pascal.bleser@opensuse.org
- update to 0.9: minor fixes and cleanup
* Sun Feb 26 2012 pascal.bleser@opensuse.org
- update to 0.8:
  * the option "-F, --recompress", which forces recompression of files whose
    name already has the ".lz" or ".tlz" suffix, has been added
  * the options "-d, --decompress" and "-t, --test" now also show compression
    ratio
  * inability to change output file attributes has been downgraded from error
    to warning
  * quote characters in messages have been changed as advised by GNU Coding
    Standards
* Wed Mar 24 2010 pascal.bleser@opensuse.org
- update to 0.6:
  * some small portability problems have been fixed
  * updates to the manual
* Mon Feb 15 2010 pascal.bleser@opensuse.org
- update to 0.5:
  * parallel decompression has been implemented
* Wed Jan 27 2010 pascal.bleser@opensuse.org
- update to 0.3:
  * the "--data-size" option has been added
  * the output file is now removed if plzip is interrupted
  * this version automatically chooses the smallest possible
    dictionary size for each member during compression, saving
    memory during decompression
  * regular files are now opened in binary mode on non-POSIX
    platforms defining the O_BINARY macro
* Tue Jan 19 2010 pascal.bleser@opensuse.org
- initial version (0.2)
